@@ -29,7 +29,7 @@ BEGIN {
 
 our @ISA = q(Exporter);
 our @EXPORT = qw($config $logger $zx_api create_config);
-our $VERSION = q(0.08);
+our $VERSION = q(0.09);
 
 our $config = {};
 our $logger;
@@ -207,7 +207,6 @@ sub store_cache {
 sub init {
 	my ($opt) = @_;
 
-	_set_binmode();
 	_set_basename(caller);
 	_set_id($opt->{id});
 	_set_logger($opt);
@@ -295,10 +294,14 @@ sub send {
 sub create_config {
 	require Zabbix::ServerScript::DefaultConfig;
 
-	init({
+	my ($opt) = @_;
+	$opt = {
 		console => 1,
 		verbose => 1,
-	});
+		(defined $opt ? %$opt : ()),
+	};
+	print Dumper($opt);
+	init($opt);
 
 	my $term = Term::ReadLine->new('Zabbix::ServerScript');
 	(my $module_dir = dirname($INC{q(Zabbix/ServerScript/DefaultConfig.pm)})) =~ s|//|/|g;
